'use strict';

angular.module('smaApp.view-recipes-filter', [])

.config(function ($stateProvider, $urlRouterProvider) {
    $stateProvider
        .state('app.recipes-filter', {
            url: '/recipes-filter',
            views: {
                'menuContent': {
                    templateUrl: 'view-recipes-filter/view-recipes-filter.html',
                    controller: 'RecipesFilterController'
                }
            }
        })
})


.controller('RecipesFilterController', ['$scope', '$http', '$state', '$ionicPopup', '$ionicScrollDelegate', function ($scope, $http, $state, $ionicPopup, $ionicScrollDelegate) {
    
    $scope.ageVisable = false;
    $scope.ingredientVisable = false;
    $scope.timeVisable = false;
    $scope.typeVisable = false;
    
    $scope.$on('$ionicView.enter', function(e) {
        
        $scope.changeFilters();
        
        if(typeof window.analytics !== undefined)
        {
            window.analytics.trackView('Filter Recipes');
        }
        
    });
    
    $scope.ingredients = [
        {id: 1, text: 'Aubergine', checked:false},
        {id: 2, text: 'Beef', checked:false},
        {id: 3, text: 'Broccoli', checked:false},
        {id: 4, text: 'Butternut squash', checked:false},
        {id: 5, text: 'Chicken', checked:false},
        {id: 6, text: 'Cod', checked:false},
        {id: 7, text: 'Haddock', checked:false},
        {id: 8, text: 'Lamb', checked:false},
        {id: 9, text: 'Lentil', checked:false},
        {id: 10, text: 'Pasta', checked:false},
        {id: 11, text: 'Pork', checked:false},
        {id: 12, text: 'Salmon', checked:false},
        {id: 13, text: 'Sweet potato', checked:false},
        {id: 14, text: 'Tuna', checked:false},
        {id: 15, text: 'Turkey', checked:false}
    ];
    
    $scope.ages = [
        {id: 1, text: 'First food', value: '0', checked:false},
        {id: 2, text: 'From 6 months', value: '6', checked:false},
        {id: 3, text: 'From 7 months', value: '7', checked:false},
        {id: 4, text: 'From 8 months', value: '8', checked:false},
        {id: 5, text: 'From 9 months', value: '9', checked:false},
        {id: 6, text: 'From 10 months', value: '10', checked:false},
        {id: 7, text: 'From 11 months', value: '11', checked:false}
    ];    
    
    $scope.times = [
        {id: 1, text: 'Under 10 minutes', value: '10', checked:false},
        {id: 2, text: 'Under 20 minutes', value: '20', checked:false},
        {id: 3, text: 'Under 30 minutes', value: '30', checked:false},
        {id: 4, text: 'Under 40 minutes', value: '40', checked:false}
    ];  
    
    $scope.mealTypes = [
        {id: 1, text: 'Breakfast', checked:false},
        {id: 2, text: 'First food', checked:false},
        {id: 3, text: 'Pudding', checked:false},
        {id: 4, text: 'Lunch', checked:false},
        {id: 4, text: 'Tea', checked:false},
        {id: 4, text: 'Snack', checked:false}
    ];  
    
    $scope.changeFilters = function()
    {
        ageFilter = [];
        timeFilter = [];
        typeFilter = [];
        ingredientFilter = [];
        
        filteredRecipes = [];
        
        // INGREDIENTS
        
        for(var i=0;i<$scope.ingredients.length;i++)
        {
            if($scope.ingredients[i].checked)
            {
                ingredientFilter.push($scope.ingredients[i].text.toLowerCase());
            }
        }
        
        // AGE
        
        for(i=0;i<$scope.ages.length;i++)
        {
            if($scope.ages[i].checked)
            {
                ageFilter.push($scope.ages[i].value);
            }
        }
        
        // MEAL TYPE
        
        for(i=0;i<$scope.mealTypes.length;i++)
        {
            if($scope.mealTypes[i].checked)
            {
                typeFilter.push($scope.mealTypes[i].text);
            }
        }
        
        // TIME
        
        for(i=0;i<$scope.times.length;i++)
        {
            if($scope.times[i].checked)
            {
                timeFilter.push($scope.times[i].value);
            }
        }
        
    }
    
    $scope.applyNoFilter = function()
    {
        ageFilter = [];
        timeFilter = [];
        typeFilter = [];
        ingredientFilter = [];
        filteredRecipes = recipes;
        showResults();
    }
    
    $scope.showAge = function (p) {
        
        $scope.ageVisable = !$scope.ageVisable;
        
        checkDropdownIcon($scope.ageVisable,'age-dd');
    }
    
    $scope.filterItems = function()
    {
        // nothing selected
        if((timeFilter.length==0)&&(typeFilter.length==0)&&(ageFilter.length==0)&&(ingredientFilter.length==0))
        { 
           filteredRecipes = recipes; 
           showResults();
        }
        else
        {
           searchForItems();
        }
    }
    
    function searchForItems ()
    {  
    
        for(var r=0;r<recipes.length;r++)
        {
                var ingredientCheck=false;
                var ageCheck=false;
                var typeCheck=false;
                var timeCheck=false;

                var ingredientHappy=false;
                var ageHappy=false;
                var typeHappy=false;
                var timeHappy=false;

                var menuItem = recipes[r];

                if((menuItem.Ingredients!=undefined)&&(ingredientFilter.length!=0))
                {
                        for(var i = 0;i<menuItem.Ingredients.Ingredient.length;i++)
                        {
                            if(menuItem.Ingredients.Ingredient[i].Title!=undefined)
                            {
                                var ing = menuItem.Ingredients.Ingredient[i].Title;

                                for(var g = 0;g<ingredientFilter.length;g++) // check all ingredients
                                {

                                    if(ing.indexOf(ingredientFilter[g]) !== -1) // recipe contains the ingredient
                                    {
                                        ingredientCheck=true;
                                    }    

                                }    
                            }
                        }

                }

                if((ingredientFilter.length>0)&&(ingredientCheck))
                {
                    ingredientHappy=true;
                }
                else if(ingredientFilter.length==0)
                {
                    ingredientHappy=true;
                }

                if(ageFilter.length!=0) // AGE
                {

                    for(i = 0;i<ageFilter.length;i++) 
                    {
                       if(menuItem.AgeSuitability==parseInt(ageFilter[i]))
                       {
                           ageCheck=true;
                       }

                    }
                }

                if((ageFilter.length>0)&&(ageCheck))
                {
                    ageHappy=true;
                }
                else if(ageFilter.length==0)
                {
                    ageHappy=true;
                }

                if(timeFilter.length!=0) // TIME
                {
                    for(i = 0;i<timeFilter.length;i++) // check all times
                    {
                        //console.log('pt:'+menuItem.PreparationTime);
                       if(menuItem.PreparationTime<=parseInt(timeFilter[i]))
                       {
                           timeCheck=true;
                       }
                    }
                }


                if((timeFilter.length>0)&&(timeCheck))
                {
                    timeHappy=true;
                }
                else if(timeFilter.length==0)
                {
                    timeHappy=true;
                }

                if(typeFilter.length!=0) // TYPE
                {
                    for(i = 0;i<typeFilter.length;i++) // check all ages
                    {
                        if(menuItem.MealType!=undefined)
                        {
                           var mt = menuItem.MealType;

                           if(mt.indexOf(typeFilter[i]) !== -1)
                           {
                               typeCheck=true;
                           }

                        }
                    }
                }

                if((typeFilter.length>0)&&(typeCheck))
                {
                    typeHappy=true;
                }
                else if(typeFilter.length==0)
                {
                    typeHappy=true;
                }


                // No matching ingredient found? Return false to exclude this item.
                if((ingredientHappy)&&(ageHappy)&&(typeHappy)&&(timeHappy))
                {
                    // add item
                    filteredRecipes.push(menuItem);
                }
            
        }
        
       showResults();
    }
    
    
    function checkDropdownIcon(c,dd)
    {
        if(c)
        {
            document.getElementById(dd).getElementsByClassName('menu-expand')[0].className = 'icon menu-collapse';
        }
        else
        {
            document.getElementById(dd).getElementsByClassName('menu-collapse')[0].className = 'icon menu-expand';
        }
        
        // reset scroll depth
        $ionicScrollDelegate.resize();
    }
    
    $scope.showIngredient = function (p) {
        
        $scope.ingredientVisable = !$scope.ingredientVisable;
        
        checkDropdownIcon($scope.ingredientVisable,'ing-dd');
    }
    
    $scope.showTime = function (p) {
        
        $scope.timeVisable = !$scope.timeVisable;
        
        checkDropdownIcon($scope.timeVisable,'time-dd');
    }
    
    $scope.showType = function (p) {
        
        $scope.typeVisable = !$scope.typeVisable;
        
        checkDropdownIcon($scope.typeVisable,'type-dd');
    }
    
    function showResults()
    {       
        $state.go('app.recipes-results');
    }

}])